@@ -1,6 +1,11 @@
-# $Id: qqnorm.aov.R,v 1.2 2003/01/02 15:40:09 warnes Exp $
+# $Id: qqnorm.aov.R,v 1.3 2003/03/07 15:48:35 warnes Exp $
 #
 # $Log: qqnorm.aov.R,v $
+# Revision 1.3  2003/03/07 15:48:35  warnes
+#
+# - Minor changes to code to allow the package to be provided as an
+#   S-Plus chapter.
+#
 # Revision 1.2  2003/01/02 15:40:09  warnes
 # - Renamed first parameter to match qqnorm generic.
 #
@@ -10,6 +15,7 @@
 #
 #
 
+if(is.R())
 qqnorm.aov <- function (y, full = FALSE, label = FALSE, omit = NULL,
                         xlab = paste(if(full) "" else "Half", " Normal plot"),
                         ylab = "Effects", ...)
